==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/SecretRefFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretRefFluentImpl<A extends SecretRefFluent<A>> extends BaseFluent<A> implements SecretRefFluent<A>{
  public SecretRefFluentImpl() {
  }
  public SecretRefFluentImpl(SecretRef instance) {
    this.withSecretKey(instance.getSecretKey()); 
    this.withSecretName(instance.getSecretName()); 
  }
  private String secretKey;
  private String secretName;
  public String getSecretKey() {
    return this.secretKey;
  }
  public A withSecretKey(String secretKey) {
    this.secretKey=secretKey; return (A) this;
  }
  public Boolean hasSecretKey() {
    return this.secretKey != null;
  }
  public String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public Boolean hasSecretName() {
    return this.secretName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SecretRefFluentImpl that = (SecretRefFluentImpl) o;
    if (secretKey != null ? !secretKey.equals(that.secretKey) :that.secretKey != null) return false;
    if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKey,  secretName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKey != null) { sb.append("secretKey:"); sb.append(secretKey + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/SecretRefFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretRefFluentImpl<A extends SecretRefFluent<A>> extends BaseFluent<A> implements SecretRefFluent<A>{
  public SecretRefFluentImpl() {
  }
  public SecretRefFluentImpl(SecretRef instance) {
    if (instance != null) {
      this.withSecretKey(instance.getSecretKey());
      this.withSecretName(instance.getSecretName());
    }
  }
  private String secretKey;
  private String secretName;
  public String getSecretKey() {
    return this.secretKey;
  }
  public A withSecretKey(String secretKey) {
    this.secretKey=secretKey; return (A) this;
  }
  public Boolean hasSecretKey() {
    return this.secretKey != null;
  }
  public String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public Boolean hasSecretName() {
    return this.secretName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretRefFluentImpl that = (SecretRefFluentImpl) o;
    if (!java.util.Objects.equals(secretKey, that.secretKey)) return false;

    if (!java.util.Objects.equals(secretName, that.secretName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKey,  secretName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKey != null) { sb.append("secretKey:"); sb.append(secretKey + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName); }
    sb.append("}");
    return sb.toString();
  }
  
}
